@@ -2,7 +2,7 @@ package Hades::Realm::Exporter;
 use strict;
 use warnings;
 use base qw/Hades/;
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub new {
 	my ( $cls, %args ) = ( shift(), scalar @_ == 1 ? %{ $_[0] } : @_ );
@@ -624,7 +624,7 @@ Quick summary of what the module does:
 	Hades->run({
 		eval => 'Kosmos {
 			[curae penthos] :t(Int) :d(2) :p :pr :c :r :i(1, GROUP)
-			geras $nosoi :t(Int) :d(5) :i { if ($self->penthos == $nosoi) { return $self->curae; } } 
+			geras $nosoi :t(Int) :d(5) :i { if (penthos() == $nosoi) { return curae; } } 
 		}',
 		realm => 'Exporter',
 	});
